@@ -314,13 +314,18 @@ cs_environment_change(GtkWidget *widget, gpointer data)
             error = TRUE;
         }
         
+        nm_environment_manager_set_active(clicked_env);
+        
+        gchar message[80];
         if (error == FALSE) {
-            nm_environment_manager_set_active(clicked_env);
-            gchar message[80];
             sprintf(message, "Environment %s applied successfully", clicked_env);
-            g_debug("message: %s", message);
-            hildon_banner_show_information(NULL, NULL, message);
         }
+        else {
+            sprintf(message, "Environment %s applied with errors", clicked_env);
+        }
+        
+        g_debug("message: %s", message);
+        hildon_banner_show_information(NULL, NULL, message);
         
     }
 }
